Installation
============

Molo requires `Python`_ (version >=3.5) to be installed. This installation method also requires `pip`_ as well as `virtualenv`_. All three of these must be installed before following the installation steps below.

Installing Molo
---------------

Molo can be then installed using::

    $ virtualenv ve
    $ source ve/bin/activate
    (ve)$ pip install molo.core

.. _python: https://www.python.org/
.. _pip: https://pip.pypa.io/en/latest/index.html
.. _virtualenv: https://virtualenv.pypa.io/en/stable/installation/
